@@ -22,13 +22,7 @@
 #include "gconf-stock-icons.h"
 #include "gconf-tree-model.h"
 #include <gconf/gconf-client.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkobject.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtktreemodelsort.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 #include <string.h>
 
 
@@ -98,11 +92,13 @@ gconf_bookmarks_update_menu (GtkWidget *menu)
 {
 	GSList *list, *tmp;
 	GtkWidget *menuitem, *window;
+	GConfClient *client;
 
 	window = g_object_get_data (G_OBJECT (menu), "editor-window");
+	client = gconf_client_get_default ();
 	
 	/* Get the old list and then set it */
-	list = gconf_client_get_list (gconf_client_get_default (),
+	list = gconf_client_get_list (client,
 				     "/apps/gconf-editor/bookmarks", GCONF_VALUE_STRING, NULL);
 
 	if (list != NULL) {
@@ -121,6 +117,8 @@ gconf_bookmarks_update_menu (GtkWidget *menu)
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 		gtk_widget_show_all (menuitem);
 	}
+
+	g_object_unref (client);
 }
 
 static void
@@ -149,9 +147,12 @@ void
 gconf_bookmarks_add_bookmark (const char *path)
 {
 	GSList *list, *tmp;
+	GConfClient *client;
+
+	client = gconf_client_get_default ();
 
 	/* Get the old list and then set it */
-	list = gconf_client_get_list (gconf_client_get_default (),
+	list = gconf_client_get_list (client,
 				     "/apps/gconf-editor/bookmarks", GCONF_VALUE_STRING, NULL);
 
 	/* FIXME: We need error handling here, also this function leaks memory */
@@ -167,15 +168,21 @@ gconf_bookmarks_add_bookmark (const char *path)
 	/* Append the new bookmark */
 	list = g_slist_append (list, g_strdup (path));
 	
-	gconf_client_set_list (gconf_client_get_default (),
+	gconf_client_set_list (client,
 			       "/apps/gconf-editor/bookmarks", GCONF_VALUE_STRING, list, NULL);
 	g_slist_free (list);
+	g_object_unref (client);
 }
 
-void
+static void
 remove_notify_id (gpointer data)
 {
-	gconf_client_notify_remove (gconf_client_get_default (), GPOINTER_TO_INT (data));
+	GConfClient *client;
+
+	client = gconf_client_get_default ();
+	gconf_client_notify_remove (client, GPOINTER_TO_INT (data));
+
+	g_object_unref (client);
 }
 
 void
@@ -219,12 +226,15 @@ gconf_bookmarks_hook_up_menu (GConfEditorWindow *window,
                         return;
 
                 have_icons = gconf_value_get_bool (value);
-
                 gconf_bookmarks_set_have_icons (menu, have_icons);
+
+                gconf_value_free (value);
         }
 
 	if ( ! gconf_client_key_is_writable (client, "/apps/gconf-editor/bookmarks", NULL)) {
 		gtk_widget_set_sensitive (add_bookmark, FALSE);
 		gtk_widget_set_sensitive (edit_bookmarks, FALSE);
 	}
+
+	g_object_unref (client);
 }
