@@ -18,6 +18,8 @@
 
 #include <config.h>
 
+#include <gnome.h>
+
 #include "gconf-editor-window.h"
 
 #include "gconf-bookmarks.h"
@@ -1388,10 +1390,9 @@ gconf_editor_window_finalize (GObject *object)
 		gconf_client_notify_remove (client, window->icons_notify_id);
 
 	g_object_unref (client);
-
-	/* FIXME: unref client?*/
+	g_object_unref (window->client);
 	
-	G_OBJECT_CLASS(gconf_editor_window_parent_class)->finalize (object);
+	G_OBJECT_CLASS (gconf_editor_window_parent_class)->finalize (object);
     
 }
 
