@@ -25,25 +25,8 @@
 #include "gconf-cell-renderer.h"
 #include "gconf-key-editor.h"
 
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkcellrenderer.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtksizegroup.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkvbbox.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libintl.h>
 #include <string.h>
 
 enum
@@ -142,6 +125,9 @@ gconf_key_editor_create_combo_box (GConfKeyEditor *editor)
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Integer"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Boolean"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("String"));
+	/* Translators: this refers to "Floating point":
+	 * see http://en.wikipedia.org/wiki/Floating_point
+	 */
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Float"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("List"));
 
