@@ -1,3 +1,22 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/*
+ * Copyright (C) 2001, 2002 Anders Carlsson <andersca@gnu.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
 #include <config.h>
 
 #include <string.h>
@@ -466,9 +485,23 @@ gconf_tree_model_tree_model_init (GtkTreeModelIface *iface)
 	iface->unref_node = gconf_tree_model_unref_node;
 }
 
+static void
+gconf_tree_model_finalize (GObject *obj)
+{
+	GConfTreeModel *model = GCONF_TREE_MODEL (obj);
+
+	if (model->client) {
+		g_object_unref (model->client);
+		model->client = NULL;
+	}
+
+	G_OBJECT_CLASS (gconf_tree_model_parent_class)->finalize (obj);
+}
+
 static void
 gconf_tree_model_class_init (GConfTreeModelClass *klass)
 {
+	G_OBJECT_CLASS (klass)->finalize = gconf_tree_model_finalize;
 }
 
 static void
